@@ -36,6 +36,9 @@
 // To ensure that Profiling does not add any runtime overhead when it 
 // is turned off, these macros expand to null.
 //////////////////////////////////////////////////////////////////////
+extern "C" void Tau_start_timer(void * function_info);
+extern "C" void Tau_stop_timer(void * function_info); 
+
 #define TAU_TYPE_STRING(profileString, str) static string profileString(str);
 #define TAU_PROFILE(name, type, group) \
 	static TauGroup_t tau_gr = group; \
@@ -43,13 +46,16 @@
 	Profiler tauFP(&tauFI, tau_gr); 
 #define TAU_PROFILE_TIMER(var, name, type, group) \
 	static TauGroup_t var##tau_gr = group; \
-	static FunctionInfo var##fi(name, type, var##tau_gr, #group); \
-	Profiler var(&var##fi, var##tau_gr, true); 
+	static FunctionInfo var##fi(name, type, var##tau_gr, #group); 
+
+//	Profiler var(&var##fi, var##tau_gr, true); 
 
 // Construct a Profiler obj and a FunctionInfo obj with an extended name
 // e.g., FunctionInfo loop1fi(); Profiler loop1(); 
-#define TAU_PROFILE_START(var) var.Start();
-#define TAU_PROFILE_STOP(var)  var.Stop();
+#define TAU_PROFILE_START(var) if (var##tau_gr & RtsLayer::TheProfileMask()) \
+ 				Tau_start_timer(&var##fi);
+#define TAU_PROFILE_STOP(var)  if (var##tau_gr & RtsLayer::TheProfileMask()) \
+				Tau_stop_timer(&var##fi);
 #define TAU_PROFILE_STMT(stmt) stmt;
 #define TAU_PROFILE_EXIT(msg)  Profiler::ProfileExit(msg); 
 #define TAU_PROFILE_INIT(argc, argv) RtsLayer::ProfileInit(argc, argv);
@@ -58,12 +64,15 @@
 #define TAU_PROFILE_SET_CONTEXT(context) RtsLayer::setMyContext(context);
 #define TAU_PROFILE_SET_GROUP_NAME(newname) tauFI.SetPrimaryGroupName(newname);
 #define TAU_PROFILE_TIMER_SET_GROUP_NAME(t, newname) t##fi.SetPrimaryGroupName(newname);
+#define TAU_PROFILE_TIMER_SET_NAME(t, newname)	t##fi.SetName(newname);
+#define TAU_PROFILE_TIMER_SET_TYPE(t, newname)  t##fi.SetType(newname);
+#define TAU_PROFILE_TIMER_SET_GROUP(t, id) t##fi.SetProfileGroup(id); 
 
 #define TAU_GLOBAL_TIMER(timer, name, type, group) static FunctionInfo timer##fi(name, type, group, #group);
-#define TAU_GLOBAL_TIMER_START(timer) FunctionInfo *timer##fptr = &timer##fi; \
+#define TAU_GLOBAL_TIMER_START(timer) {FunctionInfo *timer##fptr = &timer##fi; \
         int tau_tid = RtsLayer::myThread(); \
         Profiler *timer = new Profiler(timer##fptr, timer##fptr != (FunctionInfo *) 0 ? timer##fptr->GetProfileGroup() : TAU_DEFAULT, true, tau_tid); \
-        timer->Start(tau_tid);
+        timer->Start(tau_tid); }
 
 #define TAU_GLOBAL_TIMER_STOP()  {int tau_threadid = RtsLayer::myThread(); \
                 Profiler::CurrentProfiler[tau_threadid]->Stop(tau_threadid);}
@@ -77,11 +86,27 @@
 #endif /* PROFILE_CALLSTACK */
 
 #define TAU_DB_DUMP() Profiler::DumpData();
+#define TAU_DB_DUMP_PREFIX(prefix) Profiler::DumpData(false, RtsLayer::myThread(), prefix);
+#define TAU_DB_DUMP_INCR() Profiler::DumpData(true);
 #define TAU_DB_PURGE() Profiler::PurgeData();
+#define TAU_GET_FUNC_NAMES(functionList, num) Profiler::theFunctionList(&functionList, &num);
+#define TAU_DUMP_FUNC_NAMES() Profiler::dumpFunctionNames();
+#ifdef TAU_MULTIPLE_COUNTERS
+#define TAU_GET_COUNTER_NAMES(counterList, num) MultipleCounterLayer::theCounterList(&counterList, &num);
+#else //TAU_MULTIPLE_COUNTERS
+#define TAU_GET_COUNTER_NAMES(counterList, num) Profiler::theCounterList(&counterList, &num);
+#endif //TAU_MULTIPLE_COUNTERS
+#define TAU_GET_FUNC_VALS(v1,v2,v3,v4,v5,v6,v7,v8) \
+                               Profiler::getFunctionValues(v1,v2,&v3,&v4,&v5,&v6,&v7,&v8);
+#define TAU_DUMP_FUNC_VALS(v1,v2) \
+                               Profiler::dumpFunctionValues(v1,v2);
+#define TAU_DUMP_FUNC_VALS_INCR(v1,v2) \
+                               Profiler::dumpFunctionValues(v1,v2,true);
 
 // UserEvents
 #define TAU_REGISTER_EVENT(event, name)  	TauUserEvent event(name);
 #define TAU_EVENT(event, data) 		 	(event).TriggerEvent(data);
+#define TAU_EVENT_SET_NAME(event, name) 	(event).SetEventName(name);
 #define TAU_EVENT_DISABLE_MIN(event) 		(event).SetDisableMin(true);
 #define TAU_EVENT_DISABLE_MAX(event) 		(event).SetDisableMax(true);
 #define TAU_EVENT_DISABLE_MEAN(event) 		(event).SetDisableMean(true);
@@ -121,16 +146,29 @@
 #define TAU_PROFILE_STMT(stmt) 
 #define TAU_PROFILE_EXIT(msg)
 #define TAU_PROFILE_INIT(argc, argv)
+#define TAU_INIT(argc, argv) 
 #define TAU_PROFILE_SET_NODE(node)
 #define TAU_PROFILE_SET_CONTEXT(context)
 #define TAU_PROFILE_SET_GROUP_NAME(newname)
 #define TAU_PROFILE_TIMER_SET_GROUP_NAME(t, newname)
+#define TAU_PROFILE_TIMER_SET_NAME(t, newname)
+#define TAU_PROFILE_TIMER_SET_TYPE(t, newname)
+#define TAU_PROFILE_TIMER_SET_GROUP(t, id)
 #define TAU_PROFILE_CALLSTACK()    
 #define TAU_DB_DUMP()
+#define TAU_DB_DUMP_PREFIX(prefix) 
+#define TAU_DB_DUMP_INCR()
 #define TAU_DB_PURGE()
+#define TAU_GET_FUNC_NAMES(functionList, num)
+#define TAU_DUMP_FUNC_NAMES()
+#define TAU_GET_COUNTER_NAMES(counterList, num)
+#define TAU_GET_FUNC_VALS(v1,v2,v3,v4,v5,v6,v7,v8)
+#define TAU_DUMP_FUNC_VALS(v1,v2)
+#define TAU_DUMP_FUNC_VALS_INCR(v1,v2)
 
 #define TAU_REGISTER_EVENT(event, name)
 #define TAU_EVENT(event, data)
+#define TAU_EVENT_SET_NAME(event, name) 	
 #define TAU_EVENT_DISABLE_MIN(event)
 #define TAU_EVENT_DISABLE_MAX(event)
 #define TAU_EVENT_DISABLE_MEAN(event)
@@ -173,6 +211,6 @@
 #endif /* _TAU_API_H_ */
 /***************************************************************************
  * $RCSfile: TauAPI.h,v $   $Author: sameer $
- * $Revision: 1.16 $   $Date: 2002/01/15 21:30:12 $
- * POOMA_VERSION_ID: $Id: TauAPI.h,v 1.16 2002/01/15 21:30:12 sameer Exp $ 
+ * $Revision: 1.26 $   $Date: 2003/07/18 18:49:50 $
+ * POOMA_VERSION_ID: $Id: TauAPI.h,v 1.26 2003/07/18 18:49:50 sameer Exp $ 
  ***************************************************************************/
