@@ -1,3 +1,4 @@
+
 /****************************************************************************
 **			TAU Portable Profiling Package			   **
 **			http://www.acl.lanl.gov/tau		           **
@@ -63,7 +64,15 @@
 #define TAU_PROFILE_SET_CONTEXT(context)	Tau_set_context(context);
 #define TAU_PROFILE_CALLSTACK()			Tau_callstack();
 #define TAU_DB_DUMP()                           Tau_dump();
+#define TAU_DB_DUMP_PREFIX(prefix)              Tau_dump_prefix(prefix);
+#define TAU_DB_DUMP_INCR()                      Tau_dump_incr();
 #define TAU_DB_PURGE()                          Tau_purge();
+#define TAU_GET_FUNC_NAMES(functionList, num)   Tau_the_function_list(&functionList, &num);
+#define TAU_DUMP_FUNC_NAMES()                   Tau_dump_function_names();
+#define TAU_GET_COUNTER_NAMES(counterList, num) Tau_the_counter_names(counterList, num);
+#define TAU_GET_FUNC_VALS(v1,v2,v3,v4,v5,v6,v7,v8) Tau_get_function_values(v1,v2,&v3,&v4,&v5,&v6,&v7,&v8);
+#define TAU_DUMP_FUNC_VALS(functionList, num)   Tau_dump_function_values(functionList, num);
+#define TAU_DUMP_FUNC_VALS_incr(functionList, num)  Tau_dump_function_values_incr(functionList, num);
 
 /*
 #define TAU_REGISTER_EVENT(event, name)	static int tauuser##event = 1;\
@@ -79,6 +88,7 @@
                                    taufirst##event = 0; }
 				
 #define TAU_EVENT(event, data)			Tau_userevent(event, data);
+#define TAU_EVENT_SET_NAME(event, name)	Tau_set_event_name(event, name); 	
 #define TAU_REPORT_STATISTICS()		Tau_report_statistics();
 #define TAU_REPORT_THREAD_STATISTICS()  Tau_report_thread_statistics();
 #define TAU_EVENT_DISABLE_MIN(event) 	Tau_event_disable_min(event);
@@ -115,11 +125,23 @@ extern void Tau_set_node(int node);
 extern void Tau_set_context(int context);
 extern void Tau_callstack(void);
 extern int Tau_dump(void);
+extern int Tau_dump_incr(void);
 extern void Tau_purge(void);
+extern void Tau_theFunctionList(const char ***functionList, int *num);
+extern void Tau_dump_function_names();
+extern void Tau_the_counter_names(const char **counterList, int num);
+extern void Tau_get_function_values(const char **inFuncs, int numOfFuncs,
+				    double ***counterExclusiveValues,
+				    double ***counterInclusiveValues,
+				    int **numOfCalls, int **numOfSubRoutines,
+				    const char ***counterNames, int *numOfCounters);
+extern void Tau_dump_function_values(const char **functionList, int num);
+extern void Tau_dump_function_values_incr(const char **functionList, int num);
 extern void Tau_register_thread();
 extern void Tau_register_fork(int nodeid, enum TauFork_t opcode);
 extern void * Tau_get_userevent(char *name);
 extern void Tau_userevent(void *event, double data);
+extern void Tau_set_event_name(void *event, char * name);
 extern void Tau_report_statistics(void);
 extern void Tau_report_thread_statistics(void);
 extern void Tau_event_disable_min(void *event);
@@ -131,6 +153,8 @@ extern void Tau_trace_recvmsg(int type, int source, int length);
 extern TauGroup_t Tau_enable_group_name(char *group);
 extern TauGroup_t Tau_disable_group_name(char *group);
 extern TauGroup_t Tau_get_profile_group(char *group);
+extern void Tau_profile_c_timer(void **ptr, char *fname, char *type, TauGroup_t group, char *group_name);
+
 
 
 
@@ -147,14 +171,24 @@ extern TauGroup_t Tau_get_profile_group(char *group);
 #define TAU_PROFILE_STMT(stmt)
 #define TAU_PROFILE_EXIT(msg)
 #define TAU_PROFILE_INIT(argc, argv)
+#define TAU_INIT(argc, argv)			
 #define TAU_PROFILE_SET_NODE(node)
 #define TAU_PROFILE_SET_CONTEXT(context)
 #define TAU_PROFILE_CALLSTACK()
 #define TAU_DB_DUMP()
+#define TAU_DB_DUMP_PREFIX()              
+#define TAU_DB_DUMP_INCR()
 #define TAU_DB_PURGE()
+#define TAU_GET_FUNC_NAMES(functionList, num)
+#define TAU_DUMP_FUNC_NAMES()
+#define TAU_GET_COUNTER_NAMES(counterList, num)
+#define TAU_GET_FUNC_VALS(v1,v2,v3,v4,v5,v6,v7,v8)
+#define TAU_DUMP_FUNC_VALS(functionList, num)
+#define TAU_DUMP_FUNC_VALS_incr(functionList, num)
 
 #define TAU_REGISTER_EVENT(event, name)
 #define TAU_EVENT(event, data)
+#define TAU_EVENT_SET_NAME(event, name)
 #define TAU_REPORT_STATISTICS()
 #define TAU_REPORT_THREAD_STATISTICS()
 #define TAU_EVENT_DISABLE_MIN(event)
@@ -183,8 +217,10 @@ extern TauGroup_t Tau_get_profile_group(char *group);
         Tau_trace_recvmsg(type, source, length);
 
 #else /* TRACING_ON */
-#define TAU_TRACE_SENDMSG(type, destination, length)
-#define TAU_TRACE_RECVMSG(type, source, length)
+#define TAU_TRACE_SENDMSG(type, destination, length) \
+        Tau_trace_sendmsg(type, destination, length);
+#define TAU_TRACE_RECVMSG(type, source, length) \
+        Tau_trace_recvmsg(type, source, length);
 #endif /* TRACING_ON */
 
 
@@ -193,7 +229,7 @@ extern TauGroup_t Tau_get_profile_group(char *group);
 
 /***************************************************************************
  * $RCSfile: TauCAPI.h,v $   $Author: sameer $
- * $Revision: 1.16 $   $Date: 2002/01/15 22:27:42 $
- * POOMA_VERSION_ID: $Id: TauCAPI.h,v 1.16 2002/01/15 22:27:42 sameer Exp $
+ * $Revision: 1.24 $   $Date: 2003/07/18 18:49:51 $
+ * POOMA_VERSION_ID: $Id: TauCAPI.h,v 1.24 2003/07/18 18:49:51 sameer Exp $
  ***************************************************************************/
 
