@@ -20,7 +20,7 @@ using namespace std;
 
 //Helper function used to determine the counter value
 //from the event name.
-int map_eventnames(char *name)
+int PapiLayer::map_eventnames(char *name)
 {
   int i;
 
@@ -175,21 +175,39 @@ long long PapiLayer::getCounters(int tid)
 
 
 /////////////////////////////////////////////////
-int PapiLayerInit(void)
+int PapiLayer::PapiLayerInit(bool lock)
 { 
-     // Initialization routine for PAPI timers
-     if (PAPI_library_init(PAPI_VER_CURRENT) != PAPI_VER_CURRENT) {
-           cout << "Wrong version of PAPI library" << endl;
-           return -1;
-       }
+  static bool flag = true;
+
+  if(lock)
+    RtsLayer::LockDB();
+  if (flag)
+  {
+    flag = false; 
+    // Initialization routine for PAPI timers
+    if (PAPI_library_init(PAPI_VER_CURRENT) != PAPI_VER_CURRENT) {
+      cout << "Wrong version of PAPI library" << endl;
+      return -1;
+    }
   
-     if(PAPI_thread_init((unsigned long (*)(void))(RtsLayer::myThread),0) != PAPI_OK)
-       {
-	 cout << "There was a problem with papi's thread init" << endl;
-	 return -1;
-       }
+    if(PAPI_thread_init((unsigned long (*)(void))(RtsLayer::myThread),0) != PAPI_OK)
+    {
+      cout << "There was a problem with papi's thread init" << endl;
+      return -1;
+    }
      
-     return 0;
+  }
+  if(lock)
+    RtsLayer::UnLockDB();
+  return 0;
+}
+
+void PapiLayer::multiCounterPapiInit(void)
+{
+  //This function has the possibility if being called
+  //one or more times by MultipleCounter routines.
+  //Only want to do the init. once however.
+  static int initFlag = PapiLayerInit(false);
 }
 
 /////////////////////////////////////////////////
