@@ -38,6 +38,9 @@
 #ifdef FUJITSU
 #include "Profile/fujitsu.h"
 #endif /* FUJITSU */
+#ifdef TAU_HITACHI
+#include "Profile/hitachi.h"
+#endif /* HITACHI */
 #include "Profile/Profiler.h"
 
 #ifdef TAU_XLC
@@ -187,6 +190,7 @@ TauGroup_t RtsLayer::enableProfileGroupName(char * ProfileGroup) {
 TauGroup_t RtsLayer::generateProfileGroup(void) {
   static TauGroup_t key =  0x00000001;
   key = key << 1;
+  if (key == 0x0) key = 0x1; // cycle
   return key;
 }
 
@@ -251,7 +255,11 @@ int RtsLayer::setMyNode(int NodeId, int tid) {
   TheNode() = NodeId;
 // At this stage, we should create the trace file because we know the node id
 #ifdef TRACING_ON
+#ifdef TAU_EPILOG
+// EPILOG specific function not needed here. 
+#else /* TAU_EPILOG */
   TraceEvInit(tid);
+#endif /* TAU_EPILOG */
 #endif // TRACING_ON
   return TheNode();
 }
@@ -388,13 +396,10 @@ inline double TauGetMHz(void)
   static double ratings = TauGetMHzRatings();
   return ratings;
 }
+
 ///////////////////////////////////////////////////////////////////////////
-inline unsigned long long getLinuxHighResolutionTscCounter(void)
-{
-   unsigned long high, low;
-   __asm__ __volatile__(".byte 0x0f,0x31" : "=a" (low), "=d" (high));
-   return ((unsigned long long) high << 32) + low;
-}
+extern "C" unsigned long long getLinuxHighResolutionTscCounter(void);
+// Moved to TauLinuxTimers.c 
 
 #endif /* TAU_LINUX_TIMERS */
 
@@ -480,12 +485,19 @@ double TauWindowsUsecD(void)
 }
 ///////////////////////////////////////////////////////////////////////////
 
+#ifdef TAU_MULTIPLE_COUNTERS
+void RtsLayer::getUSecD (int tid, double *values){
+  MultipleCounterLayer::getCounters(tid, values);
+}
+#else //TAU_MULTIPLE_COUNTERS
 double RtsLayer::getUSecD (int tid) {
-
 #ifdef TAU_PCL
   return PCL_Layer::getCounters(tid);
-#else  // TAU_PCL 
+#else  // TAU_PCL
 #ifdef TAU_PAPI
+  static const char *papi_env = getenv("PAPI_EVENT");
+  if (papi_env != NULL)
+    return PapiLayer::getCounters(tid);
 #ifdef TAU_PAPI_WALLCLOCKTIME
   return PapiLayer::getWallClockTime();
 #else /* TAU_PAPI_WALLCLOCKTIME */
@@ -530,7 +542,8 @@ double RtsLayer::getUSecD (int tid) {
 #endif // CPU_TIME
 #endif // TAU_PAPI
 #endif  // TAU_PCL
-        }
+}
+#endif //TAU_MULTIPLE_COUNTERS
 
 ///////////////////////////////////////////////////////////////////////////
 //Note: This is similar to Tulip event classes during tracing
@@ -1007,6 +1020,6 @@ int RtsLayer::DumpEDF(int tid)
 
 /***************************************************************************
  * $RCSfile: RtsLayer.cpp,v $   $Author: sameer $
- * $Revision: 1.36 $   $Date: 2002/01/24 23:59:14 $
- * POOMA_VERSION_ID: $Id: RtsLayer.cpp,v 1.36 2002/01/24 23:59:14 sameer Exp $ 
+ * $Revision: 1.43 $   $Date: 2002/07/26 20:10:14 $
+ * POOMA_VERSION_ID: $Id: RtsLayer.cpp,v 1.43 2002/07/26 20:10:14 sameer Exp $ 
  ***************************************************************************/
