@@ -34,6 +34,7 @@ using namespace std;
 #endif /* TAU_DOT_H_LESS_HEADERS */
 #include "Profile/Profiler.h"
 #include <stdio.h>
+#include <stdlib.h>
 
 ///////////////////////////////////////////////////////////////////////////
 // Wrappers for corresponding C++ functions follow
@@ -69,25 +70,33 @@ extern "C" void * Tau_get_profiler(char *fname, char *type, TauGroup_t group, ch
 extern "C" void Tau_start_timer(void * function_info)
 {
   FunctionInfo *f = (FunctionInfo *) function_info; 
-  Profiler *p = new Profiler(f, f->GetProfileGroup(), true);
+  TauGroup_t gr = f->GetProfileGroup();
+  if (gr & RtsLayer::TheProfileMask())
+  {
+    Profiler *p = new Profiler(f, gr, true);
 /*
 #pragma omp critical
   printf("START tid = %d, profiler= %x\n", RtsLayer::myThread(), p);
 */
 
-  p->Start();
+    p->Start();
+  }
 }
 
 ///////////////////////////////////////////////////////////////////////////
-extern "C" void Tau_stop_timer(void * f)
+extern "C" void Tau_stop_timer(void * function_info)
 {
-  Profiler *p = Profiler::CurrentProfiler[RtsLayer::myThread()];
+  FunctionInfo *f = (FunctionInfo *) function_info; 
+  if (f->GetProfileGroup() & RtsLayer::TheProfileMask())
+  {
+    Profiler *p = Profiler::CurrentProfiler[RtsLayer::myThread()];
 /*
 #pragma omp critical
   printf("STOP tid = %d, profiler= %x\n", RtsLayer::myThread(), p);
 */
-  p->Stop();
-  delete p;
+    p->Stop();
+    delete p;
+  }
 }
 
 ///////////////////////////////////////////////////////////////////////////
@@ -132,12 +141,65 @@ extern "C" int Tau_dump(void)
   return TAU_DB_DUMP();
 }
 
+///////////////////////////////////////////////////////////////////////////
+extern "C" int Tau_dump_prefix(char *prefix)
+{
+  return TAU_DB_DUMP_PREFIX(prefix);
+}
+
+///////////////////////////////////////////////////////////////////////////
+extern "C" int Tau_dump_incr(void)
+{
+  return TAU_DB_DUMP_INCR();
+}
+
+
 ///////////////////////////////////////////////////////////////////////////
 extern "C" void Tau_purge(void)
 {
   TAU_DB_PURGE();
 }
 
+extern "C" void Tau_the_function_list(const char ***functionList, int *num)
+{
+  TAU_GET_FUNC_NAMES(*functionList, *num);
+}
+
+///////////////////////////////////////////////////////////////////////////
+extern "C" void Tau_dump_function_names()
+{
+  TAU_DUMP_FUNC_NAMES();
+}
+  
+///////////////////////////////////////////////////////////////////////////
+extern "C" void Tau_the_counter_names(const char **counterList, int num)
+{
+  TAU_GET_COUNTER_NAMES(counterList, num);
+}
+
+///////////////////////////////////////////////////////////////////////////
+extern "C" void Tau_get_function_values(const char **inFuncs, int numOfFuncs,
+					double ***counterExclusiveValues,
+					double ***counterInclusiveValues,
+					int **numOfCalls, int **numOfSubRoutines,
+					const char ***counterNames, int *numOfCounters)
+{
+  TAU_GET_FUNC_VALS(inFuncs,numOfFuncs,*counterExclusiveValues,*counterInclusiveValues,
+		    *numOfCalls,*numOfSubRoutines,*counterNames,*numOfCounters);
+}
+
+///////////////////////////////////////////////////////////////////////////
+extern "C" void Tau_dump_function_values(const char **functionList, int num)
+{
+  TAU_DUMP_FUNC_VALS(functionList,num);
+}
+
+///////////////////////////////////////////////////////////////////////////
+extern "C" void Tau_dump_function_values_incr(const char **functionList, int num)
+{
+  TAU_DUMP_FUNC_VALS_INCR(functionList,num);
+}
+
 ///////////////////////////////////////////////////////////////////////////
 extern "C" void Tau_register_thread(void)
 {
@@ -211,12 +273,60 @@ extern "C" TauGroup_t Tau_disable_all_groups(void)
   return TAU_DISABLE_ALL_GROUPS();
 }
 
+/* TAU's totalnodes implementation follows */
+///////////////////////////////////////////////////////////////////////////
+extern "C" int& tau_totalnodes(int set_or_get, int value)
+{
+  static int nodes = 1;
+  if (set_or_get == 1) /* SET (in is 1) , GET (out is 0) */
+  {
+    nodes = value;
+  }
+  return nodes;
+}
+
+#ifdef TAU_MPI
+TAU_REGISTER_EVENT(sendevent,"Message size sent to all nodes");
+TauUserEvent**& TheMsgVolEvent()
+{
+  static TauUserEvent **u = 0; 
+  return u;
+}
+/* OLD 
+TauUserEvent **u;
+*/
+int register_events(void)
+{
+  char str[256];
+  int i;
+  TheMsgVolEvent() = (TauUserEvent **) malloc(sizeof(TauUserEvent *)*tau_totalnodes(0,0));
+  for (i =0; i < tau_totalnodes(0,0); i++)
+  {
+    sprintf(str, "Message size sent to node %d", i);
+    TheMsgVolEvent()[i] = (TauUserEvent *) new TauUserEvent((const char *)str);
+  }
+  return 0;
+}
+///////////////////////////////////////////////////////////////////////////
+extern "C" void Tau_trace_sendmsg(int type, int destination, int length)
+{
+  static int initialize = register_events();
+#ifdef DEBUG_PROF
+  printf("Node %d: Tau_trace_sendmsg: type %d dest %d len %d\n", 
+        RtsLayer::myNode(), type, destination, length);
+#endif /* DEBUG_PROF */
+  TAU_EVENT(sendevent, length);
+  TheMsgVolEvent()[destination]->TriggerEvent(length, RtsLayer::myThread());
+  TAU_TRACE_SENDMSG(type, destination, length);
+}
+
+#else /* !TAU_MPI */
 ///////////////////////////////////////////////////////////////////////////
 extern "C" void Tau_trace_sendmsg(int type, int destination, int length)
 {
   TAU_TRACE_SENDMSG(type, destination, length);
 }
-
+#endif /* TAU_MPI */
 ///////////////////////////////////////////////////////////////////////////
 extern "C" void Tau_trace_recvmsg(int type, int source, int length)
 {
@@ -240,6 +350,13 @@ extern "C" void Tau_userevent(void *ue, double data)
   t->TriggerEvent(data);
 } 
 
+///////////////////////////////////////////////////////////////////////////
+extern "C" void Tau_set_event_name(void *ue, char *name)
+{
+  TauUserEvent *t = (TauUserEvent *) ue;
+  t->SetEventName(name);
+}
+
 ///////////////////////////////////////////////////////////////////////////
 extern "C" void Tau_report_statistics(void)
 {
@@ -312,7 +429,7 @@ extern "C" void Tau_profile_c_timer(void **ptr, char *fname, char *type, TauGrou
 
 /***************************************************************************
  * $RCSfile: TauCAPI.cpp,v $   $Author: sameer $
- * $Revision: 1.22 $   $Date: 2002/01/16 00:40:03 $
- * VERSION: $Id: TauCAPI.cpp,v 1.22 2002/01/16 00:40:03 sameer Exp $
+ * $Revision: 1.34 $   $Date: 2003/07/22 17:39:52 $
+ * VERSION: $Id: TauCAPI.cpp,v 1.34 2003/07/22 17:39:52 sameer Exp $
  ***************************************************************************/
 
