@@ -272,6 +272,18 @@ const char * TauUserEvent::GetEventName (void) const
   return EventName.c_str();
 }
 
+// Set the event name
+void TauUserEvent::SetEventName (const char *newname)
+{
+  EventName = newname;
+}
+
+// Set the event name
+void TauUserEvent::SetEventName (string newname)
+{
+  EventName = newname;
+}
+
 bool TauUserEvent::GetDisableMin(void)
 { 
   return DisableMin;
@@ -324,11 +336,12 @@ TauUserEvent::~TauUserEvent(void)
 
 void TauUserEvent::ReportStatistics(bool ForEachThread)
 {
-  TAU_EVENT_DATATYPE TotalNumEvents, TotalSumValue, Minima, Maxima;
+  TAU_EVENT_DATATYPE TotalNumEvents, TotalSumValue, Minima, Maxima ;
   vector<TauUserEvent*>::iterator it;
 
-    cout << "TAU Runtime Statistics" <<endl;
-    cout << "*************************************************************" << endl;
+  Maxima = Minima = 0;
+  cout << "TAU Runtime Statistics" <<endl;
+  cout << "*************************************************************" << endl;
 
   for(it  = TheEventDB().begin(); it != TheEventDB().end(); it++)
   {
@@ -407,6 +420,6 @@ void TauUserEvent::ReportStatistics(bool ForEachThread)
 
 /***************************************************************************
  * $RCSfile: UserEvent.cpp,v $   $Author: sameer $
- * $Revision: 1.9 $   $Date: 1999/08/19 22:26:56 $
- * POOMA_VERSION_ID: $Id: UserEvent.cpp,v 1.9 1999/08/19 22:26:56 sameer Exp $ 
+ * $Revision: 1.11 $   $Date: 2003/05/22 00:54:34 $
+ * POOMA_VERSION_ID: $Id: UserEvent.cpp,v 1.11 2003/05/22 00:54:34 sameer Exp $ 
  ***************************************************************************/
