@@ -22,11 +22,21 @@
 #endif
 #include "pdbAll.h"
 
+/* For selective instrumentation */
+extern int processInstrumentationRequests(char *fname);
+extern bool instrumentEntity(const string& function_name);
+extern bool processFileForInstrumentation(const string& file_name);
+
 /* For C instrumentation */
 enum itemKind_t { ROUTINE, BODY_BEGIN, FIRST_EXECSTMT, BODY_END, RETURN, EXIT};
+enum tau_language_t { tau_c, tau_cplusplus, tau_fortran };
 
 /* For Pooma, add a -noinline flag */
 bool noinline_flag = false; /* instrument inlined functions by default */
+bool noinit_flag = false;   /* initialize using TAU_INIT(&argc, &argv) by default */
+bool lang_specified = false; /* implicit detection of source language using PDB file */
+bool process_this_return = false; /* for C instrumentation using a different return keyword */
+tau_language_t tau_language; /* language of the file */
 
 struct itemRef {
   itemRef(const pdbItem *i, bool isT) : item(i), isTarget(isT) {
@@ -75,7 +85,8 @@ void getCXXReferences(vector<itemRef *>& itemvec, PDB& pdb, pdbFile *file) {
        rit!=routines.end(); ++rit) 
   {
     if ( (*rit)->location().file() == file && !(*rit)->isCompilerGenerated() && 
-	 ((*rit)->kind() != pdbItem::RO_EXT) ) 
+	 ((*rit)->kind() != pdbItem::RO_EXT) && 
+	 (instrumentEntity((*rit)->fullName())) ) 
     {
 #ifdef DEBUG
         cout <<"Routine "<<(*rit)->fullName() <<" body Begin line "
@@ -126,7 +137,8 @@ void getCXXReferences(vector<itemRef *>& itemvec, PDB& pdb, pdbFile *file) {
       pdbItem::templ_t tekind = (*te)->kind();
       if (((tekind == pdbItem::TE_MEMFUNC) || 
 	  (tekind == pdbItem::TE_STATMEM) ||
-	  (tekind == pdbItem::TE_FUNC)) && ((*te)->bodyBegin().line() != 0))
+	  (tekind == pdbItem::TE_FUNC)) && ((*te)->bodyBegin().line() != 0) &&
+	  (instrumentEntity((*te)->fullName())) )
       { 
 	/* Sometimes a compiler generated routine shows up in a template.
 	   These routines (such as operator=) do not have a body position. 
@@ -171,7 +183,9 @@ void getCReferences(vector<itemRef *>& itemvec, PDB& pdb, pdbFile *file) {
   {
     pdbRoutine::locvec retlocations = (*rit)->returnLocations();
     if ( (*rit)->location().file() == file && !(*rit)->isCompilerGenerated() &&
-         ((*rit)->kind() != pdbItem::RO_EXT))
+         ((*rit)->kind() != pdbItem::RO_EXT) && ((*rit)->bodyBegin().line() != 0) 
+	 && ((*rit)->bodyEnd().line() != 0) && 
+	 (instrumentEntity((*rit)->fullName())) )
     {
         itemvec.push_back(new itemRef(*rit, BODY_BEGIN,
                 (*rit)->bodyBegin().line(), (*rit)->bodyBegin().col()));
@@ -249,7 +263,9 @@ void getFReferences(vector<itemRef *>& itemvec, PDB& pdb, pdbFile *file) {
     pdbRoutine::locvec retlocations = (*rit)->returnLocations();
     pdbRoutine::locvec stoplocations = (*rit)->stopLocations();
     if ( (*rit)->location().file() == file &&  
-	 ((*rit)->firstExecStmtLocation().file()))
+         ((*rit)->kind() != pdbItem::RO_FSTFN) &&  
+	 ((*rit)->firstExecStmtLocation().file()) && 
+	 (instrumentEntity((*rit)->fullName())) )
     {
 #ifdef DEBUG
 	cout <<"Routine " << (*rit)->fullName() <<endl;
@@ -300,31 +316,54 @@ const int INBUF_SIZE = 2048;
 /* -------------------------------------------------------------------------- */
 bool isVoidRoutine(itemRef * i)
 {
+  string return_string;
+  const pdbType *t = ((pdbRoutine *)(i->item))->signature()->returnType();
+  if ( const pdbGroup* gr = t->isGroup() )
+    return_string = gr->name();
+  else
+    return_string = t->name();
+  /* old code 
   string return_string = ((pdbRoutine *)(i->item))->signature()->returnType()->name() ;
+  */ 
   if (return_string.compare("void") == 0)
 	return true; 
   else
 	return false;
 }
 	
+/* -------------------------------------------------------------------------- */
+/* -- Returns true is return type is a reference else returns false --------- */
+/* -------------------------------------------------------------------------- */
+bool isReturnTypeReference(itemRef * i)
+{
+  const pdbType *t = ((pdbRoutine *)(i->item))->signature()->returnType();
+  if ((t->kind() == pdbItem::TY_REF) || (t->isGroup())) 
+    return true;
+  else
+    return false;
+}
+  
+
 /* -------------------------------------------------------------------------- */
 /* -- Prints TAU_PROFILE_INIT ----------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 void print_tau_profile_init(ostream& ostr, pdbCRoutine *main_routine)
 {
-   pdbType::argvec av = main_routine->signature()->arguments();
-   if (av.size() == 2) {
-     int arg_count = 0;
-     ostr<<"  TAU_INIT(";
-     for(pdbType::argvec::const_iterator argsit = av.begin();
+   if ( noinit_flag == false )
+   { /* Put TAU_INIT */
+     pdbType::argvec av = main_routine->signature()->arguments();
+     if (av.size() == 2) {
+       int arg_count = 0;
+       ostr<<"  TAU_INIT(";
+       for(pdbType::argvec::const_iterator argsit = av.begin();
          argsit != av.end(); argsit++, arg_count++)
-     {
-       ostr<<"&"<<(*argsit).name();
-       if (arg_count == 0) ostr<<", ";
+       {
+         ostr<<"&"<<(*argsit).name();
+         if (arg_count == 0) ostr<<", ";
+       }
+       ostr<<"); "<<endl;
      }
-   ostr<<"); "<<endl;
    }
-
 }
 /* -------------------------------------------------------------------------- */
 /* -- Define a TAU group after <Profile/Profiler.h> ------------------------- */
@@ -490,6 +529,10 @@ int instrumentCXXFile(PDB& pdb, pdbFile* f, string& outfile, string& group_name,
   return 0;
 }
 
+char return_nonvoid_string[256] = "return";
+char return_void_string[256] = "return";
+char use_return_void[256] = "return";
+char use_return_nonvoid[256] = "return";
 /* -------------------------------------------------------------------------- */
 /* -- BodyBegin for a routine that does return some value ------------------- */
 /* -------------------------------------------------------------------------- */
@@ -501,8 +544,8 @@ void processNonVoidRoutine(ostream& ostr, string& return_type, itemRef *i, strin
 #endif /* DEBUG */
   ostr <<"{\n\t"<<return_type<< " tau_ret_val; "<<endl;
   ostr <<"\tTAU_PROFILE_TIMER(tautimer, \""<<
-    ((pdbRoutine *)(i->item))->name() << "\", \"" <<
-    ((pdbRoutine *)(i->item))->signature()->name() << "\", ";
+    ((pdbRoutine *)(i->item))->fullName() << "\", \" " << "\",";
+    // ((pdbRoutine *)(i->item))->signature()->name() << "\", ";
 
   if (strcmp(i->item->name().c_str(), "main")==0)
   { /* it is main() */
@@ -532,8 +575,8 @@ void processNonVoidRoutine(ostream& ostr, string& return_type, itemRef *i, strin
 void processVoidRoutine(ostream& ostr, string& return_type, itemRef *i, string& group_name)
 {
   ostr <<"{ \n\tTAU_PROFILE_TIMER(tautimer, \""<<
-    ((pdbRoutine *)(i->item))->name() << "\", \"" <<
-    ((pdbRoutine *)(i->item))->signature()->name() << "\", ";
+    ((pdbRoutine *)(i->item))->fullName() << "\", \" " << "\", ";
+    //((pdbRoutine *)(i->item))->signature()->name() << "\", ";
 
   if (strcmp(i->item->name().c_str(), "main")==0)
   { /* it is main() */
@@ -559,9 +602,13 @@ void processVoidRoutine(ostream& ostr, string& return_type, itemRef *i, string&
 /* -------------------------------------------------------------------------- */
 /* -- Writes the return expression to the instrumented file  ---------------- */
 /* -------------------------------------------------------------------------- */
-void processReturnExpression(ostream& ostr, string& ret_expression)
+void processReturnExpression(ostream& ostr, string& ret_expression, itemRef *it, char *use_string)
 {
-  ostr <<"{ tau_ret_val = " << ret_expression << "; TAU_PROFILE_STOP(tautimer); return tau_ret_val; }"<<endl;
+  if (isReturnTypeReference(it))
+    ostr <<"{ TAU_PROFILE_STOP(tautimer); "<<use_string<<" "<< (ret_expression)<<"; }" <<endl;
+  else 
+    ostr <<"{ tau_ret_val = " << ret_expression << "; TAU_PROFILE_STOP(tautimer); "<<
+	use_string<<" (tau_ret_val); }"<<endl;
 }
 
 
@@ -656,14 +703,19 @@ int instrumentCFile(PDB& pdb, pdbFile* f, string& outfile, string& group_name, s
 		return_string = ((pdbRoutine *)((*it)->item))->signature()->returnType()->name() ;
 */
 		{
-   		const pdbType *t = ((pdbRoutine *)((*it)->item))->signature()->returnType();
-   		if ( const pdbGroup* gr = t->isGroup() )
-     		  return_string = gr->name();
-   		else
-     		  return_string = t->name();
+   		  const pdbType *t = ((pdbRoutine *)((*it)->item))->signature()->returnType();
+   		  if ( const pdbGroup* gr = t->isGroup() )
+		  {
+     		    return_string = gr->fullName();
+		  }
+   		  else
+		  {
+     		    return_string = t->fullName();
+		  }
 		}
 
-		if (isVoidRoutine(*it))
+		/* If return type is a reference, treat it as a void */
+	        if (isVoidRoutine(*it) || isReturnTypeReference(*it))
 		{
 #ifdef DEBUG 
 		  cout <<"Void return value "<<endl;
@@ -680,17 +732,36 @@ int instrumentCFile(PDB& pdb, pdbFile* f, string& outfile, string& group_name, s
 #ifdef DEBUG 
 		cout <<"Return "<<endl;
 #endif /* DEBUG */
-		if (strncmp((const char *)&inbuf[((*it)->col)-1], "return", 6)==0)
+ 		process_this_return = false;
+		if (strncmp((const char *)&inbuf[((*it)->col)-1], 
+			return_void_string, strlen(return_void_string))==0)
+		{
+		  process_this_return = true; 
+		  strcpy(use_return_void, return_void_string);
+	        }
+		if (strncmp((const char *)&inbuf[((*it)->col)-1], 
+			return_nonvoid_string, strlen(return_nonvoid_string))==0)
+		{
+		  process_this_return = true; 
+		  strcpy(use_return_nonvoid, return_nonvoid_string);
+	        }
+		if (strncmp((const char *)&inbuf[((*it)->col)-1], 
+			"return", strlen("return")) == 0)
+		{
+		  process_this_return = true;
+		  strcpy(use_return_void, "return");
+		  strcpy(use_return_nonvoid, "return");
+		}
+
+		if (process_this_return)
 		{
-		/* currently, the return statement cannot be a macro. It *has* 
-		   to contain "return <...> ;" syntax. */
 		  if (isVoidRoutine(*it))
 		  {	
 #ifdef DEBUG 
 		    cout <<" Return for a void routine" <<endl;
 #endif /* DEBUG */
 		    /* instrumentation code here */
-		    ostr << "{ TAU_PROFILE_STOP(tautimer); return; }" <<endl;
+		    ostr << "{ TAU_PROFILE_STOP(tautimer); "<<use_return_void<<"; }" <<endl;
 		    for (k=((*it)->col)-1; inbuf[k] !=';'; k++)
 		     ;
 		    write_from = k+1;
@@ -701,7 +772,7 @@ int instrumentCFile(PDB& pdb, pdbFile* f, string& outfile, string& group_name, s
 #ifdef DEBUG 
 		    cout <<"Return for a non void routine "<<endl;
 #endif /* DEBUG */
-		    for (k = (*it)->col+5; (inbuf[k] != ';') && (k<inbufLength) ; k++)
+		    for (k = (*it)->col+strlen(use_return_nonvoid)-1; (inbuf[k] != ';') && (k<inbufLength) ; k++)
 		      ret_expression.append(&inbuf[k], 1);
 #ifdef DEBUG
 		    cout <<"k = "<<k<<" inbuf = "<<inbuf[k]<<endl;
@@ -740,7 +811,7 @@ int instrumentCFile(PDB& pdb, pdbFile* f, string& outfile, string& group_name, s
 #ifdef DEBUG 
 		    cout <<"ret_expression = "<<ret_expression<<endl;
 #endif /* DEBUG */
-		    processReturnExpression(ostr, ret_expression); 
+		    processReturnExpression(ostr, ret_expression, *it, use_return_nonvoid); 
 		    /* instrumentation code here */
 		  }
 		}
@@ -767,13 +838,18 @@ int instrumentCFile(PDB& pdb, pdbFile* f, string& outfile, string& group_name, s
 #ifdef DEBUG 
 		cout <<"Exit" <<endl;
 #endif /* DEBUG */
-		ostr <<"{ TAU_PROFILE_EXIT(\"exit\"); ";
-		for (k = (*it)->col-1; inbuf[k] != ';' ; k++)
-		  ostr<<inbuf[k]; 
-		ostr <<"; }";
-		instrumented = true; 
-		write_from = k+1;
+		if ((strncmp(&inbuf[(*it)->col-1], "abort", strlen("abort")) == 0) 
+		  ||(strncmp(&inbuf[(*it)->col-1], "exit", strlen("exit")) == 0) )
+                {
+		  ostr <<"{ TAU_PROFILE_EXIT(\"exit\"); ";
+		  for (k = (*it)->col-1; inbuf[k] != ';' ; k++)
+		    ostr<<inbuf[k]; 
+		  ostr <<"; }";
+		  instrumented = true; 
+		  write_from = k+1;
+                }
 		break; 
+                
 	    default:
 		cout <<"Unknown option in instrumentCFile:"<<(*it)->kind<<endl;
 		instrumented = true; 
@@ -1107,7 +1183,7 @@ int main(int argc, char **argv)
 
   if (argc < 3) 
   { 
-    cout <<"Usage : "<<argv[0] <<" <pdbfile> <sourcefile> [-o <outputfile>] [-noinline] [-g groupname] [-i headerfile]"<<endl;
+    cout <<"Usage : "<<argv[0] <<" <pdbfile> <sourcefile> [-o <outputfile>] [-noinline] [-noinit] [-g groupname] [-i headerfile] [-c|-c++|-fortran] [-f <instr_req_file> ] [-rn <return_keyword>] [-rv <return_void_keyword>]"<<endl;
     return 1;
   }
   PDB p(argv[1]); if ( !p ) return 1;
@@ -1147,6 +1223,37 @@ int main(int argc, char **argv)
 #endif /* DEBUG */
           noinline_flag = true;
         }
+        if (strcmp(argv[i], "-noinit")==0)
+ 	{
+#ifdef DEBUG
+          printf("Noinit flag\n");
+#endif /* DEBUG */
+          noinit_flag = true;
+        }
+        if (strcmp(argv[i], "-c")==0)
+ 	{
+#ifdef DEBUG
+          printf("Language explicitly specified as C\n");
+#endif /* DEBUG */
+          lang_specified = true;
+	  tau_language = tau_c;
+        }
+        if (strcmp(argv[i], "-c++")==0)
+ 	{
+#ifdef DEBUG
+          printf("Language explicitly specified as C++\n");
+#endif /* DEBUG */
+          lang_specified = true;
+	  tau_language = tau_cplusplus;
+        }
+        if (strcmp(argv[i], "-fortran")==0)
+ 	{
+#ifdef DEBUG
+          printf("Language explicitly specified as Fortran\n");
+#endif /* DEBUG */
+          lang_specified = true;
+	  tau_language = tau_fortran;
+        }
         if (strcmp(argv[i], "-g") == 0)
 	{
 	  ++i;
@@ -1161,6 +1268,30 @@ int main(int argc, char **argv)
 	  header_file = string(argv[i]);
 #ifdef DEBUG
           printf("Header file %s\n", header_file.c_str());
+#endif /* DEBUG */
+  	}
+        if (strcmp(argv[i], "-f") == 0)
+	{
+	  ++i;
+	  processInstrumentationRequests(argv[i]);
+#ifdef DEBUG
+          printf("Using instrumentation requests file: %s\n", argv[i]); 
+#endif /* DEBUG */
+  	}
+        if (strcmp(argv[i], "-rn") == 0)
+	{
+	  ++i;
+	  strcpy(return_nonvoid_string,argv[i]);
+#ifdef DEBUG
+          printf("Using non void return keyword: %s\n", return_nonvoid_string);
+#endif /* DEBUG */
+  	}
+        if (strcmp(argv[i], "-rv") == 0)
+	{
+	  ++i;
+	  strcpy(return_void_string,argv[i]);
+#ifdef DEBUG
+          printf("Using void return keyword: %s\n", return_void_string);
 #endif /* DEBUG */
   	}
         break;
@@ -1176,20 +1307,54 @@ int main(int argc, char **argv)
   for (PDB::filevec::const_iterator it=p.getFileVec().begin();
        it!=p.getFileVec().end(); ++it) 
   {
-     if ((*it)->name() == string(filename)) 
-     {
+     bool instrumentThisFile = false;
+     if (((*it)->name() == string(filename)) && 
+         (instrumentThisFile = processFileForInstrumentation(string(filename))))
+     { /* should we instrument this file? Yes */
        PDB::lang_t l = p.language();
 
 #ifdef DEBUG
        cout <<" *** FILE *** "<< (*it)->name()<<endl;
        cout <<"Language "<<l <<endl;
 #endif
-       if (l == PDB::LA_CXX)
-         instrumentCXXFile(p, *it, outFileName, group_name, header_file);
-       if (l == PDB::LA_C)
-         instrumentCFile(p, *it, outFileName, group_name, header_file);
-       if (l == PDB::LA_FORTRAN)
-         instrumentFFile(p, *it, outFileName, group_name);
+       if (lang_specified)
+       { /* language explicitly specified on command line*/
+	 switch (tau_language) { 
+	   case tau_cplusplus : 
+         	instrumentCXXFile(p, *it, outFileName, group_name, header_file);
+		break;
+	   case tau_c :
+         	instrumentCFile(p, *it, outFileName, group_name, header_file);
+		break;
+	   case tau_fortran : 
+         	instrumentFFile(p, *it, outFileName, group_name);
+		break;
+	   default:
+		printf("Language unknown\n ");
+		break;
+	 }
+       }
+       else 
+       { /* implicit detection of language */
+         if (l == PDB::LA_CXX)
+           instrumentCXXFile(p, *it, outFileName, group_name, header_file);
+         if (l == PDB::LA_C)
+           instrumentCFile(p, *it, outFileName, group_name, header_file);
+         if (l == PDB::LA_FORTRAN)
+           instrumentFFile(p, *it, outFileName, group_name);
+       }
+     } /* don't instrument this file. Should we copy in to out? */
+     else
+     { 
+       if (((*it)->name() == string(filename)) &&
+         (instrumentThisFile == false))
+       { /* we should copy the file to outFile */
+         ifstream ifs(filename);
+         ofstream ofs(outFileName.c_str());
+         /* copy ifs to ofs */
+         if (ifs.is_open() && ofs.is_open())
+           ofs << ifs.rdbuf(); /* COPY */ 
+       }
      }
   }
 
@@ -1216,8 +1381,8 @@ int main(int argc, char **argv)
   
 /***************************************************************************
  * $RCSfile: tau_instrumentor.cpp,v $   $Author: sameer $
- * $Revision: 1.33 $   $Date: 2002/01/18 23:14:22 $
- * VERSION_ID: $Id: tau_instrumentor.cpp,v 1.33 2002/01/18 23:14:22 sameer Exp $
+ * $Revision: 1.45 $   $Date: 2003/07/15 17:57:49 $
+ * VERSION_ID: $Id: tau_instrumentor.cpp,v 1.45 2003/07/15 17:57:49 sameer Exp $
  ***************************************************************************/
 
 
